@@ -66,10 +66,12 @@ class CEMBASnmCAndSnm3C(AutoPathMixIn):
         self.CEMBA_SNM3C_3C_CHROM100K_RAW_ZARR_PATH = CEMBA_SNM3C_3C_CHROM100K_RAW_ZARR_PATH
         self.CEMBA_SNM3C_3C_COMPARTMENT_ZARR_PATH = CEMBA_SNM3C_3C_COMPARTMENT_ZARR_PATH
         self.CEMBA_SNM3C_3C_DOMAIN_INSULATION_ZARR_PATH = CEMBA_SNM3C_3C_DOMAIN_INSULATION_ZARR_PATH
-        self.CEMBA_SNM3C_LOOP_ANOVA_DS_PATH = CEMBA_SNM3C_LOOP_ANOVA_DS_PATH
-        self.CEMBA_SNM3C_LOOP_AND_SUMMIT_DS_PATH = CEMBA_SNM3C_LOOP_AND_SUMMIT_DS_PATH
+        self.CEMBA_SNM3C_LOOP_VALUES_AND_STATS_DS_PATH = CEMBA_SNM3C_LOOP_VALUES_AND_STATS_V2_DS_PATH
+        self.CEMBA_SNM3C_CELL_TYPE_10K_MATRIX_ANOVA_PATH = CEMBA_SNM3C_CELL_TYPE_10K_MATRIX_ANOVA_PATH
+        self.CEMBA_SNM3C_CELL_CLUSTER_10K_MATRIX_ANOVA_PATH = CEMBA_SNM3C_CELL_CLUSTER_10K_MATRIX_ANOVA_PATH
+
         self.CEMBA_SNM3C_LOOP_VALUES_DS_PATH = CEMBA_SNM3C_LOOP_VALUES_DS_PATH
-        self.CEMBA_SNM3C_DOMAIN_BOUNDARY_AND_CHI2_DS_PAT = CEMBA_SNM3C_DOMAIN_BOUNDARY_AND_CHI2_DS_PATH
+        self.CEMBA_SNM3C_DOMAIN_BOUNDARY_AND_CHI2_DS_PATH = CEMBA_SNM3C_DOMAIN_BOUNDARY_AND_CHI2_DS_PATH
         self.CEMBA_SNM3C_DOMAIN_INSULATION_SCORE_DS_PATH = CEMBA_SNM3C_DOMAIN_INSULATION_SCORE_DS_PATH
 
         # other metadata
@@ -101,6 +103,8 @@ class CEMBASnmCAndSnm3C(AutoPathMixIn):
         self.CEMBA_SNMC_DMR_MOTIF_SCAN_REGION_DS_PATH = CEMBA_SNMC_DMR_MOTIF_SCAN_REGION_DS_REMOTE_PATH
         self.CEMBA_SNMC_DMR_TF_AND_MOTIF_HITS_DS_REMOTE_PATH = CEMBA_SNMC_DMR_TF_AND_MOTIF_HITS_DS_REMOTE_PATH
         self.CEMBA_SNMC_DMR_REGION_DS_SAMPLE_CHUNK_PATH = CEMBA_SNMC_DMR_REGION_DS_SAMPLE_CHUNK_REMOTE_PATH
+        self.CEMBA_SNMC_GROUPED_DMR_MC_REGION_DS_PATH = CEMBA_SNMC_GROUPED_DMR_MC_REGION_DS_PATH
+        self.CEMBA_SNMC_GROUPED_DMR_ATAC_REGION_DS_PATH = CEMBA_SNMC_GROUPED_DMR_ATAC_REGION_DS_PATH
 
         # Integration based other modalities at cluster level
         self.CEMBA_SNMC_TO_SNM3C_CLUSTER_MAP_PATH = CEMBA_SNMC_TO_SNM3C_CLUSTER_MAP_PATH
@@ -559,6 +563,20 @@ class CEMBASnmCAndSnm3C(AutoPathMixIn):
         )
         return cool_ds
 
+    def get_m3c_matrix_anova(self, group_level='CellType'):
+        from ALLCools.mcds.cool_ds import CoolDS
+        if group_level == 'CellType':
+            path = self.CEMBA_SNM3C_CELL_TYPE_10K_MATRIX_ANOVA_PATH
+        else:
+            path = self.CEMBA_SNM3C_CELL_CLUSTER_10K_MATRIX_ANOVA_PATH
+
+        cool_ds = CoolDS(
+            cool_ds_paths=path,
+            chrom_sizes_path=self.CEMBA_SNM3C_L4REGION_COOL_DS_CHROMS_SIZES_PATH,
+            sample_weights=None,
+        )
+        return cool_ds
+
     def get_mc_cluster_to_m3c_cluster_map(self):
         import joblib
         return joblib.load(self.CEMBA_SNMC_TO_SNM3C_CLUSTER_MAP_PATH)
